| OpticStudio | Compatibility |
|-------------|:-------------:|
| 25.1.1      |  [✔][25.1.1]  |
| 24.2.2      |  [✔][24.2.2]  |
| 24.1.3      |  [✔][24.1.0]  |
| 24.1.0      |  [✔][24.1.0]  |

Older versions of OpticStudio are not tested, but they will likely work with ZOSPy.

:::{dropdown} Table legend
✔: This version works without problems.  
ℹ: The output of all ZOSPy analyses matches the direct OpticStudio output, but the OpticStudio output has shown differences with the output of the reference version (currently **OpticStudio 25 R1.01**).  
⚠: ZOSPy does not fully work.  
❌: ZOSPy does not work at all.
:::

[25.1.1]: compatibility/25-1-1
[24.2.2]: compatibility/24-2-2
[24.1.3]: compatibility/24-1-3
[24.1.0]: compatibility/24-1-0
